search_parser

package
v0.0.0-...-57c9f0f Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 23, 2026 License: MIT Imports: 3 Imported by: 0

Documentation

Overview

Package search provides event search functionality across calendars.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func IsEventInSearchResultsByInstance

func IsEventInSearchResultsByInstance(event *ical.Event, instances []*types.EventInstance) bool

IsEventInSearchResultsByInstance checks if a given event is in the EventInstance-based search results

func ParseSearchInput

func ParseSearchInput(input string) (string, string, bool)

ParseSearchInput parses a search input string in the format "/FIELD/phrase/" Returns the field, phrase, and whether the parse was successful

Types

This section is empty.

Jump to