Documentation
¶
Index ¶
- func GoToHour(weekModel *types.WeekModel, hour int) error
- func GoToMinute(weekModel *types.WeekModel, minute int) error
- func GoToMonth(weekModel *types.WeekModel, month int) error
- func GoToMonthDay(weekModel *types.WeekModel, dayOfMonth int) error
- func GoToSpecificTime(weekModel *types.WeekModel, hour, minute int) error
- func GoToYear(weekModel *types.WeekModel, year int) error
- func HandleAddEvent(m Model, count int) (tea.Model, tea.Cmd)
- func HandleCalendarPopup(m Model, count int) (tea.Model, tea.Cmd)
- func HandleChangeColor(m Model, count int) (tea.Model, tea.Cmd)
- func HandleChangeDescription(m Model, count int) (tea.Model, tea.Cmd)
- func HandleChangeDuration(m Model, count int) (tea.Model, tea.Cmd)
- func HandleChangeEndTime(m Model, count int) (tea.Model, tea.Cmd)
- func HandleChangeLink(m Model, count int) (tea.Model, tea.Cmd)
- func HandleChangeLocation(m Model, count int) (tea.Model, tea.Cmd)
- func HandleChangeStartTime(m Model, count int) (tea.Model, tea.Cmd)
- func HandleChangeTitle(m Model, count int) (tea.Model, tea.Cmd)
- func HandleClearLockedSearch(m Model, count int) (tea.Model, tea.Cmd)
- func HandleCloseForm(m Model, count int) (tea.Model, tea.Cmd)
- func HandleCopyEvent(m Model, count int) (tea.Model, tea.Cmd)
- func HandleCopySelection(m Model, count int) (tea.Model, tea.Cmd)
- func HandleCutEvent(m Model, count int) (tea.Model, tea.Cmd)
- func HandleCutSelection(m Model, count int) (tea.Model, tea.Cmd)
- func HandleDeleteSelection(m Model, count int) (tea.Model, tea.Cmd)
- func HandleEditEvent(m Model, count int) (tea.Model, tea.Cmd)
- func HandleEnterSearchMode(m Model, count int) (tea.Model, tea.Cmd)
- func HandleEnterVisualMode(m Model, count int) (tea.Model, tea.Cmd)
- func HandleExecuteSearch(m Model, count int) (tea.Model, tea.Cmd)
- func HandleExitSearchMode(m Model, count int) (tea.Model, tea.Cmd)
- func HandleExitVisualMode(m Model, count int) (tea.Model, tea.Cmd)
- func HandleGoToDay(m Model, day int) (tea.Model, tea.Cmd)
- func HandleGoToHour(m Model, hour int) (tea.Model, tea.Cmd)
- func HandleGoToMinute(m Model, minute int) (tea.Model, tea.Cmd)
- func HandleGoToMonth(m Model, month int) (tea.Model, tea.Cmd)
- func HandleGoToTime(m Model, time int) (tea.Model, tea.Cmd)
- func HandleGoToYear(m Model, year int) (tea.Model, tea.Cmd)
- func HandleHideHints(m Model, count int) (tea.Model, tea.Cmd)
- func HandleJumpToCurrentTime(m Model, count int) (tea.Model, tea.Cmd)
- func HandleJumpToEndOfDay(m Model, count int) (tea.Model, tea.Cmd)
- func HandleJumpToFirstEventOfDay(m Model, count int) (tea.Model, tea.Cmd)
- func HandleJumpToLastEventOfDay(m Model, count int) (tea.Model, tea.Cmd)
- func HandleJumpToStartOfDay(m Model, count int) (tea.Model, tea.Cmd)
- func HandleMoveDown(m Model, count int) (tea.Model, tea.Cmd)
- func HandleMoveLeft(m Model, count int) (tea.Model, tea.Cmd)
- func HandleMoveRight(m Model, count int) (tea.Model, tea.Cmd)
- func HandleMoveUp(m Model, count int) (tea.Model, tea.Cmd)
- func HandleNavigateToEventEnd(m Model, count int) (tea.Model, tea.Cmd)
- func HandleNavigateToNextEvent(m Model, count int) (tea.Model, tea.Cmd)
- func HandleNavigateToNextResult(m Model, count int) (tea.Model, tea.Cmd)
- func HandleNavigateToNextWeek(m Model, count int) (tea.Model, tea.Cmd)
- func HandleNavigateToPreviousEvent(m Model, count int) (tea.Model, tea.Cmd)
- func HandleNavigateToPreviousResult(m Model, count int) (tea.Model, tea.Cmd)
- func HandleNavigateToPreviousWeek(m Model, count int) (tea.Model, tea.Cmd)
- func HandleOpenAllDayEventURL(m Model, count int) (tea.Model, tea.Cmd)
- func HandleOpenEventURL(m Model, count int) (tea.Model, tea.Cmd)
- func HandlePasteEvent(m Model, count int) (tea.Model, tea.Cmd)
- func HandleQuit(m Model, count int) (tea.Model, tea.Cmd)
- func HandleRecurringDeleteFromPicker(m Model, count int) (tea.Model, tea.Cmd)
- func HandleRedoAction(m Model, count int) (tea.Model, tea.Cmd)
- func HandleShowRecuringDeleteDialog(m Model, count int) (tea.Model, tea.Cmd)
- func HandleStartHintTimeout(m Model, count int) (tea.Model, tea.Cmd)
- func HandleSwapSelectionEnds(m Model, count int) (tea.Model, tea.Cmd)
- func HandleToggleAgendaLayer(m Model, count int) (tea.Model, tea.Cmd)
- func HandleToggleAllDayGrid(m Model, count int) (tea.Model, tea.Cmd)
- func HandleToggleEventTextColor(m Model, count int) (tea.Model, tea.Cmd)
- func HandleToggleHints(m Model, count int) (tea.Model, tea.Cmd)
- func HandleUndoAction(m Model, count int) (tea.Model, tea.Cmd)
- func HandleUpdateHintsForSequence(m Model, count int) (tea.Model, tea.Cmd)
- func HandleViewEventDetails(m Model, count int) (tea.Model, tea.Cmd)
- func HandleZoomIn(m Model, count int) (tea.Model, tea.Cmd)
- func HandleZoomOut(m Model, count int) (tea.Model, tea.Cmd)
- func VisualMoveDown(weekModel *types.WeekModel, count int) tea.Cmd
- func VisualMoveLeft(weekModel *types.WeekModel, count int) tea.Cmd
- func VisualMoveRight(weekModel *types.WeekModel, count int) tea.Cmd
- func VisualMoveUp(weekModel *types.WeekModel, count int) tea.Cmd
- type ActionHandler
- type Model
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GoToMinute ¶
GoToMinute jumps cursor to the specified minute within the current hour
func GoToMonthDay ¶
GoToMonthDay jumps to the specified day of the month, preserving time
func GoToSpecificTime ¶
GoToSpecificTime jumps cursor to the specified hour and minute on current day
func HandleAddEvent ¶
HandleAddEvent shows the add event form
func HandleChangeDescription ¶
func HandleClearLockedSearch ¶
func HandleCloseForm ¶
HandleCloseForm closes the currently visible form
func HandleCopyEvent ¶
HandleCopyEvent performs copy operation on event at cursor
func HandleCopySelection ¶
HandleCopySelection copies all events in visual selection
func HandleCutEvent ¶
HandleCutEvent performs cut operation (copy + delete) on event at cursor
func HandleCutSelection ¶
HandleCutSelection cuts all events in visual selection (copy then delete)
func HandleEditEvent ¶
HandleEditEvent shows the comprehensive edit event form for non-recurring, timed events
func HandleEnterSearchMode ¶
HandleEnterSearchMode enters search mode (called from app layer with vimState access)
func HandleEnterVisualMode ¶
HandleEnterVisualMode enters visual mode and sets anchor
func HandleExitVisualMode ¶
HandleExitVisualMode exits visual mode back to normal
func HandleGoToDay ¶
HandleGoToDay jumps to the specified day of the month, preserving time (gd##)
func HandleGoToHour ¶
HandleGoToHour jumps cursor to the specified hour on the current day (gh##)
func HandleGoToMinute ¶
HandleGoToMinute jumps cursor to the specified minute within the current hour (gm##)
func HandleGoToMonth ¶
HandleGoToMonth jumps to the specified month, preserving day and time if possible (gM##)
func HandleGoToTime ¶
HandleGoToTime jumps cursor to the specified hour and minute on current day (gt####)
func HandleGoToYear ¶
HandleGoToYear jumps to the specified year, preserving month, day and time if possible (gY####)
func HandleHideHints ¶
HandleHideHints hides key hints and cancels any pending timeout
func HandleJumpToCurrentTime ¶
HandleJumpToCurrentTime implements t command
func HandleJumpToEndOfDay ¶
HandleJumpToEndOfDay implements G command
func HandleJumpToFirstEventOfDay ¶
HandleJumpToFirstEventOfDay implements ^ command
func HandleJumpToLastEventOfDay ¶
HandleJumpToLastEventOfDay implements $ command
func HandleJumpToStartOfDay ¶
HandleJumpToStartOfDay implements gg command
func HandleMoveDown ¶
MoveDown implements j command
func HandleMoveLeft ¶
HandleMoveLeft implements h command
func HandleMoveRight ¶
HandleMoveRight implements l command
func HandleMoveUp ¶
MoveUp implements k command
func HandleNavigateToEventEnd ¶
HandleNavigateToEventEnd handles e command - vim-like 'e' behavior for event ends
func HandleNavigateToNextEvent ¶
HandleNavigateToNextEvent handles w command - finds and navigates to next event across all weeks
func HandleNavigateToNextResult ¶
HandleNavigateToNextResult moves cursor to next search result (actual implementation)
func HandleNavigateToNextWeek ¶
NavigateToNextWeek implements L command
func HandleNavigateToPreviousResult ¶
HandleNavigateToPreviousResult moves cursor to previous search result (actual implementation)
func HandleNavigateToPreviousWeek ¶
NavigateToPreviousWeek implements H command
func HandleOpenAllDayEventURL ¶
HandleOpenAllDayEventURL opens the URL of the selected all-day event
func HandleOpenEventURL ¶
HandleOpenEventURL opens the URL of the event at cursor position
func HandlePasteEvent ¶
HandlePasteEvent performs paste operation at cursor position
func HandleQuit ¶
HandleQuitApplication quits the application
func HandleRecurringDeleteFromPicker ¶
HandleRecurringDeleteFromPicker shows recurring delete dialog for selected event from picker
func HandleRedoAction ¶
HandleRedoAction performs redo operation
func HandleShowRecuringDeleteDialog ¶
HandleShowRecuringDeleteDialog shows recurring delete dialog for event under cursor
func HandleStartHintTimeout ¶
HandleStartHintTimeout starts timeout for showing key hints
func HandleSwapSelectionEnds ¶
HandleSwapSelectionEnds swaps cursor and anchor positions
func HandleToggleAgendaLayer ¶
HandleToggleAgendaLayer shows the agenda picker popup for the current cursor day
func HandleToggleHints ¶
HandleToggleHints toggles keyhints visibility based on current state
func HandleUndoAction ¶
HandleUndoAction performs undo operation
func HandleUpdateHintsForSequence ¶
HandleUpdateHintsForSequence immediately updates hints if visible, or starts timeout if not
func HandleZoomIn ¶
HandleZoomIn implements zoom_in command
func HandleZoomOut ¶
HandleZoomOut implements zoom_out command
func VisualMoveDown ¶
VisualMoveDown implements j in visual mode
func VisualMoveLeft ¶
VisualMoveLeft implements h in visual mode
func VisualMoveRight ¶
VisualMoveRight implements l in visual mode
Types ¶
type ActionHandler ¶
ActionHandler defines the interface for all vim actions
type Model ¶
type Model struct {
WeekModel types.WeekModel
EventManager *ical_crud.EventManager
Form *huh.Form
ShowForm bool
RecurringOperation *types.RecurringEventOperation // Store current recurring operation
Quitting bool
VimState *keybinds.VimState
VimRegistry *keybinds.CommandRegistry
KeyHints *keyhints.KeyHintSystem
WaitingForKeyTimeout bool
SyncInterval int // CalDAV background sync interval in seconds (0 = disabled)
}
Model represents the main application state